package com.dayou.service.impl;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.dayou.dto.CustomerDTO;
import com.dayou.entity.Customer;
import com.dayou.entity.Districts;
import com.dayou.mapper.CustomerMapper;
import com.dayou.service.ICustomerService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dayou.service.IDistrictsService;
import com.fasterxml.jackson.databind.util.BeanUtil;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.dayou.utils.ExcelUtil;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.ArrayList;
import org.springframework.transaction.annotation.Transactional;
import com.dayou.enums.BatchTaskTypeEnum;

/**
 * <p>
 * 客户表 服务实现类
 * </p>
 *
 * @author wucl
 * @since 2023-01-10
 */
@Service
public class CustomerServiceImpl extends ServiceImpl<CustomerMapper, Customer> implements ICustomerService {


    @Autowired
    private IDistrictsService districtsService;

    @Override
    @SuppressWarnings("unchecked")
    public Page<CustomerDTO> selectPage(Page page,Customer customer){
        Page result = this.page(page, new QueryWrapper<Customer>(customer));
        List<CustomerDTO> xRecords = new ArrayList<>();
        List<Customer> records = result.getRecords();
        records.stream().forEach(x->{
            CustomerDTO dto = new CustomerDTO();
            BeanUtils.copyProperties(x,dto);
            if (StrUtil.isNotEmpty(x.getCity())){
                List<Long> citys = JSON.parseArray(x.getCity(), Long.class);
                List<Districts> list = districtsService.list(new LambdaQueryWrapper<Districts>().select(Districts::getExtName).in(Districts::getId, citys));
                dto.setFirstCity(list.get(1).getExtName());
                dto.setSecCity(list.get(2).getExtName());
            }
            xRecords.add(dto);
        });
        result.setRecords(xRecords);
        return result;
    }


    @Override
    public CustomerDTO detail(Long id){
        Customer byId = this.getById(id);
        CustomerDTO dto = new CustomerDTO();
        BeanUtils.copyProperties(byId,dto);
        dto.setCitys(JSON.parseArray(byId.getCity(),Long.class));
        return dto;
    }

    @Override
    public Boolean add(CustomerDTO customer){
        customer.setCity(JSON.toJSONString(customer.getCitys()));
        return  this.save(customer);
    }

    @Override
    public Boolean update(CustomerDTO customer){
        customer.setCity(JSON.toJSONString(customer.getCitys()));
        return  this.updateById(customer);
    }

    @Override
    public Boolean delete(Long id){
        //逻辑删除
        return this.removeById(id);
    }
}
